@@ -596,6 +596,10 @@ gnm_go_data_vector_load_len (GODataVector *dat)
 			vec->as_col = (vec->val->v_array.y > vec->val->v_array.x);
 			break;
 		}
+		case VALUE_ERROR :
+			new_len = 0;
+			break;
+
 		default :
 			new_len = 1;
 			vec->as_col = TRUE;
@@ -1329,7 +1333,7 @@ gnm_go_data_matrix_load_values (GODataMatrix *dat)
 		minimum = G_MAXDOUBLE;
 		for (col = 0; col < size.columns; col ++)
 			for (row = 0; row < size.rows; row++) {
-				v = mat->val->v_array.vals[row][col];
+				v = mat->val->v_array.vals[col][row];
 				cur = col * size.rows + row;
 				if (VALUE_IS_EMPTY_OR_ERROR (v)) {
 					vals[row * size.columns + col] = go_nan;
